@@ -285,7 +285,7 @@ KNotification *KNotification::event(const QString &eventid, const QString &title
     notify->setTitle(title);
     notify->setText(text);
     notify->setPixmap(pixmap);
-    notify->setComponentName(componentName);
+    notify->setComponentName(flags & DefaultEvent ? QStringLiteral("plasma_workspace") : componentName);
 
     QTimer::singleShot(0, notify, SLOT(sendEvent()));
 
@@ -365,7 +365,7 @@ QString KNotification::appName() const
     QString appname;
 
     if (d->flags & DefaultEvent) {
-        appname = QLatin1String("kde");
+        appname = QLatin1String("plasma_workspace");
     } else if (!d->componentName.isEmpty()) {
         appname = d->componentName;
     } else {
